/**************************************************************************//**
 * @file main.c
 * @brief Capacitive touch example for EFM32ZG-STK3200
 *
 * @version 4.0.0
 ******************************************************************************
 * @section License
 * <b>(C) Copyright 2014 Silicon Labs, http://www.silabs.com</b>
 *******************************************************************************
 *
 * This file is licensed under the Silabs License Agreement. See the file
 * "Silabs_License_Agreement.txt" for details. Before using this software for
 * any purpose, you must agree to the terms of that agreement.
 *
 ******************************************************************************/

#include <stdio.h>
#include <stdlib.h>

#include "em_device.h"
#include "em_adc.h"
#include "em_chip.h"
#include "em_cmu.h"
#include "em_emu.h"
#include "em_rtc.h"
#include "em_gpio.h"
#include "em_pcnt.h"
#include "capsense.h"



//#include "display.h"
//#include "textdisplay.h"
//#include "retargettextdisplay.h"

#define LFRCO_FREQUENCY                 32768
#define WAKEUP_INTERVAL_MS              1000
#define RTC_COUNT_BETWEEN_WAKEUP        (((LFRCO_FREQUENCY * WAKEUP_INTERVAL_MS) / 1000)-1)
#define RTC_COUNT_PART1        			RTC_COUNT_BETWEEN_WAKEUP/3
#define RTC_COUNT_PART2       			RTC_COUNT_PART1*2
#define RTC_COUNT_100ms       			RTC_COUNT_BETWEEN_WAKEUP/10
#define RTC_COUNT_1ms       			RTC_COUNT_BETWEEN_WAKEUP/1000


#define ClearDisplayLine0 		GPIO_PinOutClear(gpioPortE, 10);		//Display Line 0
#define ClearDisplayLine1 		GPIO_PinOutClear(gpioPortF,  5);  		//Display Line 1
#define ClearDisplayLine2		GPIO_PinOutClear(gpioPortF,  4);  		//Display Line 2
#define ClearDisplayLine3 		GPIO_PinOutClear(gpioPortF,  3);  		//Display Line 3
#define ClearDisplayLine4 		GPIO_PinOutClear(gpioPortF,  2);  		//Display Line 4
#define ClearDisplayLine5 		GPIO_PinOutClear(gpioPortC, 15);  		//Display Line 5
#define ClearDisplayLine6 		GPIO_PinOutClear(gpioPortC, 14);  		//Display Line 6
#define ClearDisplayLine7 		GPIO_PinOutClear(gpioPortC, 13);  		//Display Line 7
#define ClearDisplayLine8 		GPIO_PinOutClear(gpioPortC, 11);  		//Display Line 8
#define ClearDisplayLine9 		GPIO_PinOutClear(gpioPortC, 10);    	//Display Line 9
#define ClearDisplayLineSTBY 	GPIO_PinOutClear(gpioPortC,  9);    	//Display Line for STBY LEDs

#define SetDisplayLine0 		GPIO_PinOutSet(gpioPortE, 10);			//Display Line 0
#define SetDisplayLine1 		GPIO_PinOutSet(gpioPortF,  5);  		//Display Line 1
#define SetDisplayLine2			GPIO_PinOutSet(gpioPortF,  4);  		//Display Line 2
#define SetDisplayLine3 		GPIO_PinOutSet(gpioPortF,  3);  		//Display Line 3
#define SetDisplayLine4 		GPIO_PinOutSet(gpioPortF,  2);  		//Display Line 4
#define SetDisplayLine5 		GPIO_PinOutSet(gpioPortC, 15);  		//Display Line 5
#define SetDisplayLine6 		GPIO_PinOutSet(gpioPortC, 14);  		//Display Line 6
#define SetDisplayLine7 		GPIO_PinOutSet(gpioPortC, 13);  		//Display Line 7
#define SetDisplayLine8 		GPIO_PinOutSet(gpioPortC, 11);  		//Display Line 8
#define SetDisplayLine9 		GPIO_PinOutSet(gpioPortC, 10);    		//Display Line 9
#define SetDisplayLineSTBY 		GPIO_PinOutSet(gpioPortC,  9);    		//Display Line for STBY LEDs


#define EncoderOn 				GPIO_PinOutSet(gpioPortC, 2);    		//Rotory encoder power
#define EncoderOff 				GPIO_PinOutClear(gpioPortC, 2);    		//Rotory encoder power

#define ClearDisplaySecCol0		GPIO_PinOutClear(gpioPortC,  8);		//Display Seconds column 0
#define ClearDisplaySecCol1		GPIO_PinOutClear(gpioPortD,  7);		//Display Seconds column 1
#define ClearDisplaySecCol2		GPIO_PinOutClear(gpioPortD,  6);		//Display Seconds column 2
#define ClearDisplaySecCol3		GPIO_PinOutClear(gpioPortD,  5);		//Display Seconds column 3
#define ClearDisplaySecCol4		GPIO_PinOutClear(gpioPortB, 14);		//Display Seconds column 4
#define ClearDisplaySecCol5		GPIO_PinOutClear(gpioPortB, 13);		//Display Seconds column 5

#define ClearDisplayMinCol0		GPIO_PinOutClear(gpioPortB, 11);		//Display Minutes column 0
#define ClearDisplayMinCol1		GPIO_PinOutClear(gpioPortA, 10);		//Display Minutes column 1
#define ClearDisplayMinCol2		GPIO_PinOutClear(gpioPortA,  9);		//Display Minutes column 2
#define ClearDisplayMinCol3		GPIO_PinOutClear(gpioPortA,  8);		//Display Minutes column 3
#define ClearDisplayMinCol4		GPIO_PinOutClear(gpioPortA,  2);		//Display Minutes column 4
#define ClearDisplayMinCol5		GPIO_PinOutClear(gpioPortA,  1);		//Display Minutes column 5

#define ClearDisplayHourCol0	GPIO_PinOutClear(gpioPortA,  0);		//Display Hours column 0
#define ClearDisplayHourCol1	GPIO_PinOutClear(gpioPortE, 13);		//Display Hours column 1
#define ClearDisplayHourCol2	GPIO_PinOutClear(gpioPortE, 12);		//Display Hours column 2

#define ClearDisplayDayCol		GPIO_PinOutClear(gpioPortE, 11);		//Display Days column


#define SetDisplaySecCol0		GPIO_PinOutSet(gpioPortC,  8);			//Display Seconds column 0
#define SetDisplaySecCol1		GPIO_PinOutSet(gpioPortD,  7);			//Display Seconds column 1
#define SetDisplaySecCol2		GPIO_PinOutSet(gpioPortD,  6);			//Display Seconds column 2
#define SetDisplaySecCol3		GPIO_PinOutSet(gpioPortD,  5);			//Display Seconds column 3
#define SetDisplaySecCol4		GPIO_PinOutSet(gpioPortB, 14);			//Display Seconds column 4
#define SetDisplaySecCol5		GPIO_PinOutSet(gpioPortB, 13);			//Display Seconds column 5

#define SetDisplayMinCol0		GPIO_PinOutSet(gpioPortB, 11);			//Display Minutes column 0
#define SetDisplayMinCol1		GPIO_PinOutSet(gpioPortA, 10);			//Display Minutes column 1
#define SetDisplayMinCol2		GPIO_PinOutSet(gpioPortA,  9);			//Display Minutes column 2
#define SetDisplayMinCol3		GPIO_PinOutSet(gpioPortA,  8);			//Display Minutes column 3
#define SetDisplayMinCol4		GPIO_PinOutSet(gpioPortA,  2);			//Display Minutes column 4
#define SetDisplayMinCol5		GPIO_PinOutSet(gpioPortA,  1);			//Display Minutes column 5

#define SetDisplayHourCol0		GPIO_PinOutSet(gpioPortA,  0);			//Display Hours column 0
#define SetDisplayHourCol1		GPIO_PinOutSet(gpioPortE, 13);			//Display Hours column 1
#define SetDisplayHourCol2		GPIO_PinOutSet(gpioPortE, 12);			//Display Hours column 2

#define SetDisplayDayCol		GPIO_PinOutSet(gpioPortE, 11);			//Display Days column

static volatile uint32_t msTicks; /* counts 1ms timeTicks */

int DisplayMultiplex;
int encoder;
int count;
int seccount;
int flash;
int mode;
uint32_t ADCvoltageAV[8];
int ADCvoltageAVcount;
uint32_t   BattVoltage;




uint32_t ADCread(void);
void display(int Seconds, int Minutes, int Hours, int Days);
void DisplayCol(int Seconds, int Minutes, int Hours, int Days, int Col);

/**************************************************************************//**
 * @brief PCNT1_IRQHandler
 * Interrupt Service Routine for PCNT1 Interrupt Line
 *****************************************************************************/
void PCNT0_IRQHandler(void)
{
  if(PCNT0->IF & PCNT_IF_UF)
  {
	  PCNT_IntClear(PCNT0, PCNT_IF_UF); //Clear overflow interrupt flag
	  count = count + 60;
  }
  if(PCNT0->IF & PCNT_IF_OF)
  {
	  PCNT_IntClear(PCNT0, PCNT_IF_OF); //Clear underflow interrupt flag
	  count = count - 60;
	  if (count < 0)count = 604799;
  }
}


/**************************************************************************//**
 * @brief RTC Interrupt Handler, clears the flag.
 *****************************************************************************/
void RTC_IRQHandler(void)
{
  if(RTC->IF & RTC_IF_COMP0)
  {
	  /* Clear interrupt source */
	  RTC_IntClear(RTC_IFC_COMP0);
	  count++;
	  if(count > 604799)count = 0;
	  flash = 1;
	  ADC_Start(ADC0, adcStartSingle);

	  //if (mode == 1)
	  //{
	//	  GPIO_PinOutSet(gpioPortE,13);
	//	  GPIO_PinOutClear(gpioPortA, 0);
	//	  GPIO_PinOutClear(gpioPortB,11);
	//	  flash = 0;
	 // }
	//  else if(mode == 2)
	//  {
	//	  if(flash == 0)GPIO_PinOutClear(gpioPortA,1);
	//	  flash++;
	//	  if (flash == 2) flash = 0;
	//  }

  }
  if(RTC->IF & RTC_IF_COMP1)
  {
	  RTC_IntClear(RTC_IFC_COMP1);
	 /* if(mode == 1)
	  {
		  if (flash == 0)
		  {
			  GPIO_PinOutClear(gpioPortE,13);
			  GPIO_PinOutSet(gpioPortA, 0);
			  GPIO_PinOutClear(gpioPortB,11);
			  RTC_CompareSet(1, RTC_COUNT_PART2);
		  }
		  else if (flash == 1)
		  {
			  GPIO_PinOutClear(gpioPortE,13);
			  GPIO_PinOutClear(gpioPortA, 0);
			  GPIO_PinOutSet(gpioPortB,11);
			  RTC_CompareSet(1, RTC_COUNT_PART1);
		  }
		  flash++;
	  }
	  else if(mode == 2)
	  {
		  GPIO_PinOutSet(gpioPortA,1);
	  }*/
	  flash = 0;

  }





}


/**************************************************************************//**
 * @brief SysTick_Handler
 * Interrupt Service Routine for system tick counter
 *****************************************************************************/
void SysTick_Handler(void)
{
  msTicks++;       /* increment counter necessary in Delay()*/
  if(msTicks>1)msTicks = 0;


}








/**************************************************************************//**
 * @brief  Setup RTC/RTCC
 * On compare match with compare channel, clear counter and set interrupt
 *****************************************************************************/
void setupRtc(void)
{
  /* Configuring clocks in the Clock Management Unit (CMU) */
	//CMU_ClockDivSet(CMU_LFAPRESC0_REG, cmuClkDiv_4096);
  CMU_ClockEnable(cmuClock_CORELE, true);     /* Enable CORELE clock */

  /* Starting LFRCO and waiting until it is stable */
  CMU_OscillatorEnable(cmuOsc_LFXO, true, true);


  /* Routing the LFRCO clock to the RTC */
  CMU_ClockSelectSet(cmuClock_LFA,cmuSelect_LFXO);
  CMU_ClockEnable(cmuClock_RTC, true);


  RTC_Init_TypeDef rtcInit = RTC_INIT_DEFAULT;


  /* Setting the compare value of the RTC */
  RTC_CompareSet(0, RTC_COUNT_BETWEEN_WAKEUP);
  RTC_CompareSet(1, RTC_COUNT_PART1);

  /* Enabling Interrupt from RTC */
  RTC_IntEnable(RTC_IEN_COMP0);
  RTC_IntEnable(RTC_IEN_COMP1);
  NVIC_ClearPendingIRQ(RTC_IRQn);
  NVIC_EnableIRQ(RTC_IRQn);

  /* Initialize the RTC */
  RTC_Init(&rtcInit);

}


/**************************************************************************//**
 * @brief  Setup PCNT
 *
 *****************************************************************************/
void setupPCNT(void)
{
	CMU_ClockEnable(cmuClock_CORELE, true);     /* Enable CORELE clock */
	  CMU_ClockEnable(cmuClock_GPIO, true);       /* Enable clock for GPIO module */
	  CMU_ClockEnable(cmuClock_PCNT0, true);      /* Enable clock for PCNT module */
	  /* Setup SysTick timer for 1 msec interrupts  */
	  if (SysTick_Config(SystemCoreClockGet() / 1000)) while (1) ;

	  /* Configure PC0 and PC1 as inputs to drive pulse counter */
	  GPIO_PinModeSet(gpioPortC, 0, gpioModeInput, 0);
	  GPIO_PinModeSet(gpioPortC, 1, gpioModeInput, 0);





	  /* Set configuration for pulse counter */
	  PCNT_Init_TypeDef pcntInit1 =
	  {
	    .mode       = pcntModeExtQuad,    /* clocked by PCNT1_S0IN */
	    .counter    = 0,                  /* Set initial value to 0 */
	    .top        = 0,                 /* Set top to max value */
	    .negEdge    = false,              /* positive edges */
	    .countDown  = false,              /* up count */
	    .filter     = false,               /* filter enabled */
	    .hyst		= false,
	    .s1CntDir   = true,
	    .cntEvent   = pcntCntEventBoth,
	    .auxCntEvent= pcntCntEventNone,
	    .s0PRS		= pcntPRSCh0,
	    .s1PRS		= pcntPRSCh0
	  };

	  /* Initialize Pulse Counter */
	  PCNT_Init(PCNT0, &pcntInit1);

	  /* Enable PCNT direction change interrupt */
	  PCNT_IntEnable(PCNT0, PCNT_IF_OF | PCNT_IF_UF);

	  /* Enable PCNT1 interrupt vector in NVIC */
	  NVIC_EnableIRQ(PCNT0_IRQn);

	  /* Route PCNT1 input to location 0 -> PCNT1_S0IN on PC4
	     and PCNT1_S1IN in PC5 */
	  PCNT0->ROUTE = PCNT_ROUTE_LOCATION_LOC2;
}


/**************************************************************************//**
 * @brief Delays number of msTick Systicks (typically 1 ms)
 * @param dlyTicks Number of ticks to delay
 *****************************************************************************/
static void Delay(uint32_t dlyTicks)
{
  uint32_t curTicks;

  curTicks = msTicks;
  while ((msTicks - curTicks) < dlyTicks) ;
}



/***************************************************************************//**
* @brief
*   Configure ADC usage for this application.
*******************************************************************************/
static void ADCConfig(void)
{
	CMU_ClockEnable(cmuClock_ADC0, true);
  ADC_Init_TypeDef       init       = ADC_INIT_DEFAULT;
  ADC_InitSingle_TypeDef singleInit = ADC_INITSINGLE_DEFAULT;

  /* Init common settings for both single conversion and scan mode */
  init.timebase = ADC_TimebaseCalc(0);
  /* Might as well finish conversion as quickly as possibly since polling */
  /* for completion. */
  /* Set ADC clock to 7 MHz, use default HFPERCLK */
  init.prescale = ADC_PrescaleCalc(1000000, 0);

  /* WARMUPMODE must be set to Normal according to ref manual before */
  /* entering EM2. In this example, the warmup time is not a big problem */
  /* due to relatively infrequent polling. Leave at default NORMAL, */

  ADC_Init(ADC0, &init);

  /* Init for single conversion use, measure VDD/3 with 1.25 reference. */
  singleInit.reference  = adcRef2V5;
  singleInit.input      = adcSingleInpCh4;
  singleInit.resolution = adcRes12Bit;

  /* The datasheet specifies a minimum aquisition time when sampling vdd/3 */
  /* 32 cycles should be safe for all ADC clock frequencies */
  singleInit.acqTime = adcAcqTime256;

  ADC_InitSingle(ADC0, &singleInit);
}


uint32_t ADCread(void)
{
	uint32_t sample;
	uint32_t   voltage;
	int i;
	voltage = 0;
    /* Wait while conversion is active */
    while (ADC0->STATUS & ADC_STATUS_SINGLEACT) ;

    /* Get ADC result */
    sample = ADC_DataSingleGet(ADC0);

    /* Calculate supply voltage relative to 2.5V reference */
    ADCvoltageAV[ADCvoltageAVcount] = (sample * 2500 * 2) / 4096;
    ADCvoltageAVcount++;
    if(ADCvoltageAVcount >= 8)ADCvoltageAVcount = 0;
    for(i = 0; i < 8; ++i)
    {
    	voltage = voltage + ADCvoltageAV[i];
    }
    voltage = voltage>>3;
    //voltage =  (sample * 2500 * 2) / 4096;
    return voltage;
}





void DisplayCol(int Seconds, int Minutes, int Hours, int Days, int Col)
{
	if(Seconds >= 1  + Col){SetDisplaySecCol0}   else {ClearDisplaySecCol0}		//Set or Clear Line depending on whether this LED On the face is on at this value of Seconds
	if(Seconds >= 11 + Col){SetDisplaySecCol1}   else {ClearDisplaySecCol1}
	if(Seconds >= 21 + Col){SetDisplaySecCol2}   else {ClearDisplaySecCol2}
	if(Seconds >= 31 + Col){SetDisplaySecCol3}   else {ClearDisplaySecCol3}
	if(Seconds >= 41 + Col){SetDisplaySecCol4}   else {ClearDisplaySecCol4}
	if(Seconds >= 51 + Col){SetDisplaySecCol5}   else {ClearDisplaySecCol5}
	if(Col == 9){if(Seconds >= 0){SetDisplaySecCol5}   else {ClearDisplaySecCol5}}

	if(Minutes >= 1  + Col){SetDisplayMinCol0}   else {ClearDisplayMinCol0}		//Set or Clear Line depending on whether this LED On the face is on at this value of Minutes
	if(Minutes >= 11 + Col){SetDisplayMinCol1}   else {ClearDisplayMinCol1}
	if(Minutes >= 21 + Col){SetDisplayMinCol2}   else {ClearDisplayMinCol2}
	if(Minutes >= 31 + Col){SetDisplayMinCol3}   else {ClearDisplayMinCol3}
	if(Minutes >= 41 + Col){SetDisplayMinCol4}   else {ClearDisplayMinCol4}
	if(Minutes >= 51 + Col){SetDisplayMinCol5}   else {ClearDisplayMinCol5}
	if(Col == 9){if(Minutes >= 0){SetDisplayMinCol5}   else {ClearDisplayMinCol5}}

	if(Hours   >= 1  + Col){SetDisplayHourCol0}  else {ClearDisplayHourCol0}	//Set or Clear Line depending on whether this LED On the face is on at this value of Hours
	if(Hours   >= 11 + Col){SetDisplayHourCol1}  else {ClearDisplayHourCol1}
	if(Hours   >= 21 + Col){SetDisplayHourCol2}  else {ClearDisplayHourCol2}
	if(Col == 3){if(Hours   >= 0){SetDisplayHourCol2}  else {ClearDisplayHourCol2}}

	if(Days    >= 1  + Col){SetDisplayDayCol}    else {ClearDisplayDayCol}		//Set or Clear Line depending on whether this LED On the face is on at this value of Hours
	if(Col == 6){if(Days    >= 0){SetDisplayDayCol}    else {ClearDisplayDayCol}}
}

void display(int Seconds, int Minutes, int Hours, int Days)
{
	switch (DisplayMultiplex)
	{
		case 0:
			ClearDisplayLineSTBY    											//Display Line for STBY LEDs always clear in-case waking up
			DisplayCol(Seconds, Minutes, Hours, Days, 0);						//Set the column LEDs for these values
			SetDisplayLine0														//Display Line 0 The Line we are dealing with now
			break;

		case 1:
			ClearDisplayLineSTBY    											//Display Line for STBY LEDs always clear in-case waking up
			ClearDisplayLine0    												//Display Line 0 The previous line, must be cleared first
			DisplayCol(Seconds, Minutes, Hours, Days, 1);						//Set the column LEDs for these values
			SetDisplayLine1														//Display Line 1 The Line we are dealing with now
			break;

		case 2:
			ClearDisplayLineSTBY    											//Display Line for STBY LEDs always clear in-case waking up
			ClearDisplayLine1    												//Display Line 1 The previous line, must be cleared first
			DisplayCol(Seconds, Minutes, Hours, Days, 2);						//Set the column LEDs for these values
			SetDisplayLine2														//Display Line 2 The Line we are dealing with now
			break;

		case 3:
			ClearDisplayLineSTBY    											//Display Line for STBY LEDs always clear in-case waking up
			ClearDisplayLine2    												//Display Line 2 The previous line, must be cleared first
			DisplayCol(Seconds, Minutes, Hours, Days, 3);						//Set the column LEDs for these values
			SetDisplayLine3														//Display Line 3 The Line we are dealing with now
			break;

		case 4:
			ClearDisplayLineSTBY    											//Display Line for STBY LEDs always clear in-case waking up
			ClearDisplayLine3    												//Display Line 3 The previous line, must be cleared first
			DisplayCol(Seconds, Minutes, Hours, Days, 4);						//Set the column LEDs for these values
			SetDisplayLine4														//Display Line 4 The Line we are dealing with now
			break;

		case 5:
			ClearDisplayLineSTBY    											//Display Line for STBY LEDs always clear in-case waking up
			ClearDisplayLine4    												//Display Line 4 The previous line, must be cleared first
			DisplayCol(Seconds, Minutes, Hours, Days, 5);						//Set the column LEDs for these values
			SetDisplayLine5														//Display Line 5 The Line we are dealing with now
			break;

		case 6:
			ClearDisplayLineSTBY    											//Display Line for STBY LEDs always clear in-case waking up
			ClearDisplayLine5    												//Display Line 5 The previous line, must be cleared first
			DisplayCol(Seconds, Minutes, Hours, Days, 6);						//Set the column LEDs for these values
			SetDisplayLine6														//Display Line 6 The Line we are dealing with now
			break;

		case 7:
			ClearDisplayLineSTBY    											//Display Line for STBY LEDs always clear in-case waking up
			ClearDisplayLine6    												//Display Line 6 The previous line, must be cleared first
			DisplayCol(Seconds, Minutes, Hours, Days, 7);						//Set the column LEDs for these values
			SetDisplayLine7														//Display Line 7 The Line we are dealing with now
			break;

		case 8:
			ClearDisplayLineSTBY    											//Display Line for STBY LEDs always clear in-case waking up
			ClearDisplayLine7    												//Display Line 7 The previous line, must be cleared first
			DisplayCol(Seconds, Minutes, Hours, Days, 8);						//Set the column LEDs for these values
			SetDisplayLine8														//Display Line 8 The Line we are dealing with now
			break;

		case 9:
			ClearDisplayLineSTBY    											//Display Line for STBY LEDs always clear in-case waking up
			ClearDisplayLine8    												//Display Line 8 The previous line, must be cleared first
			DisplayCol(Seconds, Minutes, Hours, Days, 9);						//Set the column LEDs for these values
			SetDisplayLine9														//Display Line 9 The Line we are dealing with now
			break;

		case 10:
			ClearDisplayLineSTBY    											//Display Line for STBY LEDs always clear in-case waking up
			ClearDisplayLine9    												//Display Line 9 The previous line, must be cleared first


			ClearDisplayMinCol0
			ClearDisplayMinCol1
			ClearDisplayMinCol2
			ClearDisplayHourCol0
			ClearDisplayHourCol1
			ClearDisplayHourCol2


			if(GPIO_PinInGet(gpioPortF,1) == 1 && GPIO_PinInGet(gpioPortC,3) == 1)
			{
				SetDisplayMinCol0
				SetDisplayMinCol1
				SetDisplayMinCol2
			}
			else if(GPIO_PinInGet(gpioPortF,1) == 0 && GPIO_PinInGet(gpioPortC,3) == 1)
			{
				SetDisplayHourCol0
				SetDisplayHourCol1
				SetDisplayHourCol2
			}

			SetDisplayLineSTBY 													//Display Line STBY The Line we are dealing with now
			break;

		default:
			DisplayMultiplex = 0;												//we shoulden't ever get here but if we do reset to 0
		    break;
	}
	DisplayMultiplex++; 														//Increment Display Line for next time
	if (DisplayMultiplex >= 11)DisplayMultiplex = 0;							//If we just did last line go back to first
}









/**************************************************************************//**
 * @brief  Main function
 *****************************************************************************/
int main(void)
{

  int temp;
  float mah = 0;;
  uint32_t   v;
  int i;
  int tick = 0;

  int days = 0;
  int hour = 0;
  int min = 0;
  int sec = 0;
  DisplayMultiplex = 0; //Start Display Multiplex Line off at zero
mode = 1;
  encoder = 50;
  count = 0;
  seccount = 0;
  flash = 0;

  ADCvoltageAVcount = 0;
  /* Chip errata */
  CHIP_Init();
  for(i = 0; i < 8; ++i)
  {
  	ADCvoltageAV[i] = 4000;
  }





  CMU_ClockSelectSet(cmuClock_HF, cmuSelect_HFRCO);
  //CMU_HFRCOBandSet(cmuHFRCOBand_1MHz);
  CMU_ClockSelectSet(cmuClock_LFA, cmuSelect_LFXO);






  setupPCNT();

  ADCConfig();



  /* Initialize the display module. */
  //DISPLAY_Init();

  /* Retarget stdio to the display. */
//  RETARGET_TextDisplayInit();

  /* Start capacitive sense buttons */
  CAPSENSE_Init();

  /* Setting up rtc */
  setupRtc();


  GPIO_PinModeSet(gpioPortE, 10, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortF,  5, gpioModePushPullDrive, 0);
  GPIO_PinModeSet(gpioPortF,  4, gpioModePushPullDrive, 0);
  GPIO_PinModeSet(gpioPortF,  3, gpioModePushPullDrive, 0);
  GPIO_PinModeSet(gpioPortF,  2, gpioModePushPullDrive, 0);
  GPIO_PinModeSet(gpioPortC, 15, gpioModePushPullDrive, 0);
  GPIO_PinModeSet(gpioPortC, 14, gpioModePushPullDrive, 0);
  GPIO_PinModeSet(gpioPortC, 13, gpioModePushPullDrive, 0);
  GPIO_PinModeSet(gpioPortC, 11, gpioModePushPullDrive, 0);
  GPIO_PinModeSet(gpioPortC, 10, gpioModePushPullDrive, 0);
  GPIO_PinModeSet(gpioPortC,  9, gpioModePushPullDrive, 0);



  GPIO_PinModeSet(gpioPortC,  8, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortD,  7, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortD,  6, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortD,  5, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortB, 14, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortB, 13, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortB, 11, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortA, 10, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortA,  9, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortA,  8, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortA,  2, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortA,  1, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortA,  0, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortE, 13, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortE, 12, gpioModePushPullDrive, 1);
  GPIO_PinModeSet(gpioPortE, 11, gpioModePushPullDrive, 1);

  GPIO_PinModeSet(gpioPortF,  1, gpioModeInput, 0);
  GPIO_PinModeSet(gpioPortC,  3, gpioModeInput, 0);

  GPIO_PinModeSet(gpioPortC, 2, gpioModePushPullDrive, 1);
  //GPIO_PinModeSet(gpioPortC, 3, gpioModePushPullDrive, 0);

  GPIO_DriveModeSet(gpioPortC,gpioDriveModeHigh);
  GPIO_DriveModeSet(gpioPortD,gpioDriveModeHigh);
  GPIO_DriveModeSet(gpioPortE,gpioDriveModeHigh);
  GPIO_DriveModeSet(gpioPortA,gpioDriveModeHigh);
  GPIO_DriveModeSet(gpioPortB,gpioDriveModeHigh);
  CMU_ClockSelectSet(cmuClock_LFA, cmuSelect_LFXO);
  CMU_ClockDivSet(cmuClock_RTC, cmuClkDiv_1);
 // GPIO_PinOutClear(gpioPortA, 10);
  ADC_Start(ADC0, adcStartSingle);

  RTC_CompareSet(1, RTC_COUNT_100ms);
  while (1)
  {
	//  printf("%3d\n", CAPSENSE_getVal(BUTTON0_CHANNEL));
	//  CAPSENSE_Sense();
//if((CAPSENSE_getVal(BUTTON0_CHANNEL))<=35)
//{
	  BattVoltage = ADCread();

	  if (mode == 1)
	  {
		  EncoderOn
		  days  = 0;
		  hour = 0;
		  min = 0;
		  temp = count;
		  while(temp >= 86400)
		  {
			temp = temp - 86400;
			days++;
		  }
		  while(temp >= 3600)
		  {
			temp = temp - 3600;
			hour++;
		  }
		  while(temp >= 60)
		  {
			temp = temp - 60;
			min++;
		  }
		  sec = temp;



		  if(msTicks == 1)
		  {
			  display(sec, min, hour, days);
			  msTicks = 0;
		  }
		  if (BattVoltage < 3200)
		  {
				ClearDisplayLine0
				ClearDisplayLine1
				ClearDisplayLine2
				ClearDisplayLine3
				ClearDisplayLine4
				ClearDisplayLine5
				ClearDisplayLine6
				ClearDisplayLine7
				ClearDisplayLine8
				ClearDisplayLine9
				ClearDisplaySecCol0
				ClearDisplaySecCol1
				ClearDisplaySecCol2
				ClearDisplaySecCol3
				ClearDisplaySecCol4
				ClearDisplaySecCol5
				ClearDisplayMinCol0
				ClearDisplayMinCol1
				ClearDisplayMinCol2
				ClearDisplayMinCol3
				ClearDisplayMinCol4
				ClearDisplayMinCol5
				ClearDisplayHourCol0
				ClearDisplayHourCol1
				ClearDisplayHourCol2
				ClearDisplayDayCol
				SetDisplayLineSTBY
				mode = 2;
		  }
	  }
	  else if(mode == 2)
	  {
		  EncoderOff
		  if(flash == 1)
		  {
			SetDisplayHourCol0
			SetDisplayHourCol1
			SetDisplayHourCol2
		  }
		  else
		  {
			ClearDisplayHourCol0
			ClearDisplayHourCol1
			ClearDisplayHourCol2
		  }
		  if (BattVoltage > 3600) mode = 1;
		  EMU_EnterEM2(false);
	  }


	  //EMU_EnterEM2(false);

    //Delay( 100 );
//if(msTicks == 1)GPIO_PinOutSet(gpioPortE,10);
//else GPIO_PinOutClear(gpioPortE,10);

	/*  if(mode == 1)
	  {
		  GPIO_PinOutClear(gpioPortA,1);
	  }
	  else if (mode == 2)
	  {
		  RTC_CompareSet(1, RTC_COUNT_100ms);
		  GPIO_PinOutSet(gpioPortE,13);
		  GPIO_PinOutSet(gpioPortA, 0);
		  GPIO_PinOutSet(gpioPortB,11);
	  }


    days  = 1;
    hour = 0;
    min = 0;
    temp = count;
    while(temp >= 86400)
    {
    	temp = temp - 86400;
    	days++;
    }
    while(temp >= 3600)
    {
    	temp = temp - 3600;
    	hour++;
    }
    while(temp >= 60)
    {
    	temp = temp - 60;
    	min++;
    }
    sec = temp;
    v = ADCread();

    printf("   %1d\n", days);
    printf("\n");
    printf("%02d:%02d:%02d\n", hour,min,sec);
    printf("\n");
    printf("%3d\n", CAPSENSE_getVal(BUTTON0_CHANNEL));
    printf("%8d\n",(int)((float)count*0.0277778));
    printf("%3d",v);
    printf( TEXTDISPLAY_ESC_SEQ_CURSOR_HOME_VT52 );


    if(v < 2900)
    {
    	mah = ((float)count*0.0277778);
    	printf( TEXTDISPLAY_ESC_SEQ_CURSOR_HOME_VT52 );
    	printf("%02d:%02d:%02d\n", hour,min,sec);
    	 printf("%8d\n        \n        \n        \n        ",(int)mah);
    	GPIO_PinOutClear(gpioPortD,6);
    	while(1)
    	{
    		EMU_EnterEM2(false);
    	}
    }


    CAPSENSE_Sense();
    ADC_Start(ADC0, adcStartSingle);
    EMU_EnterEM2(false);*/
  }
}
